check_cuts_array — skchange

Skip to main content
`Ctrl`+`K`

# check_cuts_array

check_cuts_array(cuts: ndarray, min_size: int = 1, last_dim_size: int = 2) → ndarray

  Check array type cuts.

  Parameters:
    cutsnp.ndarray

      Array of cuts to check.

    min_sizeint, optional (default=1)

      Minimum size of the intervals obtained by the cuts.

    last_dim_sizeint, optional (default=2)

      Size of the last dimension.

  Returns:
    cutsnp.ndarray

      The unmodified input cuts array.

  Raises:
    ValueError

      If the cuts does not meet the requirements.